@@ -58,11 +58,20 @@ export const webadminPlaces = {
   vdoSavings: 'vdoSavings'
 }
 
-export const webadminToastTypes = {
+export const webadminToastTypes = { // plugin-api: NotificationType
   info: 'info',
+  success: 'success',
+  warning: 'warning',
   danger: 'danger'
 }
 
+export const entityTypes = {
+  cluster: 'Cluster',
+  host: 'Host',
+  vm: 'VirtualMachine',
+  hostDevices: 'HostDevice'
+}
+
 export const heatMapThresholds = {
   domain: [0.65, 0.75, 0.9],
   colors: ['#D4F0FA', '#F9D67A', '#EC7A08', '#CE0000']
@@ -90,10 +99,4 @@ export const storageUnitTable = [
 // number of characters before giving more space to bar chart labels
 export const utilizationListGridNameThreshold = 30
 
-export const entityTypes = {
-  cluster: 'Cluster',
-  host: 'Host',
-  vm: 'VirtualMachine'
-}
-
 export const vmUpStates = ['Up', 'PoweringUp', 'RebootInProgress', 'Paused']
